URLUtils class

Utility functions for handling URL encoding/decoding

Constructors

URLUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isDoubleEncoded(String string) → bool
Checks if a string appears to be double-encoded
isEncoded(String string) → bool
Checks if a string appears to be already URL encoded
normalizeUrlEncoding(String urlString) → String
Normalizes a URL string by decoding it once if it appears to be double-encoded
smartEncodeURIComponent(String string) → String
Smart URL encoder that ensures a string is encoded exactly once