QuilttConnectorConfiguration class
Configuration for launching the Quiltt Connector.
Constructors
- QuilttConnectorConfiguration({required String connectorId, required String appLauncherUrl, String? connectionId, String? institution, String? themeMode})
- Creates a QuilttConnectorConfiguration.
Properties
- appLauncherUrl ↔ String
-
The URL used when returning from an external app (e.g. an OAuth redirect).
getter/setter pair
- connectionId ↔ String?
-
The ID of an existing connection to reconnect to.
getter/setter pair
- connectorId ↔ String
-
The ID of the connector to launch.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- institution ↔ String?
-
An optional institution hint to pre-select in the connector.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- themeMode ↔ String?
-
The theme mode for the Connector UI.
Supported values: 'light', 'dark', 'auto'.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited