ConnectorSDKCallbackMetadata class
Metadata included with every Connector SDK callback event.
Constructors
- ConnectorSDKCallbackMetadata({required String connectorId, String? connectionId, String? profileId})
- Creates a ConnectorSDKCallbackMetadata instance.
Properties
- connectionId ↔ String?
-
The connection ID associated with the event, if available.
getter/setter pair
- connectorId ↔ String
-
The ID of the connector that triggered the event.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- profileId ↔ String?
-
The profile ID associated with the event, if available.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited