ConnectorSDKOnExitErrorCallback class

Callback payload delivered when the Connector exits with an error.

Constructors

ConnectorSDKOnExitErrorCallback({required ConnectorSDKCallbackMetadata eventMetadata})
Creates a ConnectorSDKOnExitErrorCallback instance.

Properties

eventMetadata ConnectorSDKCallbackMetadata
Metadata for the errored session.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited